\addlanguage{albanian}{loadhyph-sq.tex}{}{2}{2}
\addlanguage{croatian}{loadhyph-hr.tex}{}{2}{2}
\addlanguage{danish}{loadhyph-da.tex}{}{2}{2}
\addlanguage{dutch}{loadhyph-nl.tex}{}{2}{2}
\addlanguage{estonian}{loadhyph-et.tex}{}{2}{3}
\addlanguage{finnish}{loadhyph-fi.tex}{}{2}{2}
\addlanguage{schoolfinnish}{loadhyph-fi-x-school.tex}{}{1}{1}
\addlanguage{friulan}{loadhyph-fur.tex}{}{2}{2}
\addlanguage{hungarian}{loadhyph-hu.tex}{}{2}{2}
\addlanguage{icelandic}{loadhyph-is.tex}{}{2}{2}
\addlanguage{irish}{loadhyph-ga.tex}{}{2}{3}
\addlanguage{kurmanji}{loadhyph-kmr.tex}{}{2}{2}
\addlanguage{classiclatin}{loadhyph-la-x-classic.tex}{}{2}{2}
\addlanguage{latin}{loadhyph-la.tex}{}{2}{2}
\addlanguage{liturgicallatin}{loadhyph-la-x-liturgic.tex}{}{2}{2}
\addlanguage{latvian}{loadhyph-lv.tex}{}{2}{2}
\addlanguage{lithuanian}{loadhyph-lt.tex}{}{2}{2}
\addlanguage{macedonian}{loadhyph-mk.tex}{}{2}{2}
\addlanguage{bokmal}{loadhyph-nb.tex}{}{2}{2}
\addlanguage{norwegian}{loadhyph-nb.tex}{}{2}{2}
\addlanguage{norsk}{loadhyph-nb.tex}{}{2}{2}
\addlanguage{nynorsk}{loadhyph-nn.tex}{}{2}{2}
\addlanguage{occitan}{loadhyph-oc.tex}{}{2}{2}
\addlanguage{piedmontese}{loadhyph-pms.tex}{}{2}{2}
\addlanguage{romanian}{loadhyph-ro.tex}{}{2}{2}
\addlanguage{romansh}{loadhyph-rm.tex}{}{2}{2}
\addlanguage{slovenian}{loadhyph-sl.tex}{}{2}{2}
\addlanguage{slovene}{loadhyph-sl.tex}{}{2}{2}
\addlanguage{swedish}{loadhyph-sv.tex}{}{2}{2}
\addlanguage{turkish}{loadhyph-tr.tex}{}{2}{2}
\addlanguage{uppersorbian}{loadhyph-hsb.tex}{}{2}{2}
\addlanguage{welsh}{loadhyph-cy.tex}{}{2}{3}
