%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% This is the `armscii8.def' file (ArmSCII8 input encoding definitions).
%%
%% This file is a part of the ArmTeX project [2024/01/13 v3.0-beta5]
%%
%% ArmTeX is a system for writing in Armenian with plain TeX and/or LaTeX(2e).
%%
%% Copyright 1997 - 2024:
%%   Serguei Dachian (Serguei.Dachian_AT_univ-lille.fr),
%%   Arnak Dalalyan  (arnak.dalalyan_AT_ensae.fr),
%%   Vardan Akopian  (vakopian_AT_yahoo.com).
%%
%% ArmTeX may be distributed and/or modified under the conditions of the LaTeX
%% Project Public License, either version 1.3 of this license or (at your
%% option) any later version.
%%
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of LaTeX version
%% 2005/12/01 or later.
%%
%% ArmTeX has the LPPL maintenance status `author-maintained'.
%%
%% For more details, installation instructions and the complete list of files
%% see the provided `README' file.
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%% Begining of the code.
%%
\ProvidesFile{armscii8.def}
  [2024/01/13 v3.0-beta5 armscii8.def (ArmSCII8 input encoding definitions)]


%% Upper-case letters.
%%
\DeclareInputText{178}{\Armayb}%           Upper-case A  (Ayb)  letter.
\DeclareInputText{180}{\Armben}%           Upper-case B  (Ben)  letter.
\DeclareInputText{182}{\Armgim}%           Upper-case G  (Gim)  letter.
\DeclareInputText{184}{\Armda}%            Upper-case D  (Da)   letter.
\DeclareInputText{186}{\Armyech}%          Upper-case E  (Yech) letter.
\DeclareInputText{188}{\Armza}%            Upper-case Z  (Za)   letter.
\DeclareInputText{190}{\Arme}%             Upper-case E' (E)    letter.
\DeclareInputText{192}{\Armat}%            Upper-case U' (At)   letter.
\DeclareInputText{194}{\Armto}%            Upper-case TH (To)   letter.
\DeclareInputText{196}{\Armzhe}%           Upper-case G' (Zhe)  letter.
\DeclareInputText{198}{\Armini}%           Upper-case I  (Ini)  letter.
\DeclareInputText{200}{\Armlyun}%          Upper-case L  (Lyun) letter.
\DeclareInputText{202}{\Armkhe}%           Upper-case X  (Khe)  letter.
\DeclareInputText{204}{\Armtsa}%           Upper-case C' (Tsa)  letter.
\DeclareInputText{206}{\Armken}%           Upper-case K  (Ken)  letter.
\DeclareInputText{208}{\Armho}%            Upper-case H  (Ho)   letter.
\DeclareInputText{210}{\Armdza}%           Upper-case DZ (Dza)  letter.
\DeclareInputText{212}{\Armghat}%          Upper-case GH (Ghat) letter.
\DeclareInputText{214}{\Armtche}%          Upper-case J' (Tche) letter.
\DeclareInputText{216}{\Armmen}%           Upper-case M  (Men)  letter.
\DeclareInputText{218}{\Armhi}%            Upper-case Y  (Hi)   letter.
\DeclareInputText{220}{\Armnu}%            Upper-case N  (Nu)   letter.
\DeclareInputText{222}{\Armsha}%           Upper-case SH (Sha)  letter.
\DeclareInputText{224}{\Armvo}%            Upper-case O  (Vo)   letter.
\DeclareInputText{226}{\Armcha}%           Upper-case CH (Cha)  letter.
\DeclareInputText{228}{\Armpe}%            Upper-case P  (Pe)   letter.
\DeclareInputText{230}{\Armje}%            Upper-case J  (Je)   letter.
\DeclareInputText{232}{\Armra}%            Upper-case R' (Ra)   letter.
\DeclareInputText{234}{\Armse}%            Upper-case S  (Se)   letter.
\DeclareInputText{236}{\Armvev}%           Upper-case V  (Vev)  letter.
\DeclareInputText{238}{\Armtyun}%          Upper-case T  (Tyun) letter.
\DeclareInputText{240}{\Armre}%            Upper-case R  (Re)   letter.
\DeclareInputText{242}{\Armtso}%           Upper-case C  (Tso)  letter.
\DeclareInputText{244}{\Armvyun}%          Upper-case W  (Vyun) letter.
\DeclareInputText{246}{\Armpyur}%          Upper-case PH (Pyur) letter.
\DeclareInputText{248}{\Armke}%            Upper-case Q  (Ke)   letter.
\DeclareInputText{250}{\Armo}%             Upper-case O' (O)    letter.
\DeclareInputText{252}{\Armfe}%            Upper-case F  (Fe)   letter.


%% Lower-case letters.
%%
\DeclareInputText{179}{\armayb}%           Lower-case a  (ayb)  letter.
\DeclareInputText{181}{\armben}%           Lower-case b  (ben)  letter.
\DeclareInputText{183}{\armgim}%           Lower-case g  (gim)  letter.
\DeclareInputText{185}{\armda}%            Lower-case d  (da)   letter.
\DeclareInputText{187}{\armyech}%          Lower-case e  (eych) letter.
\DeclareInputText{189}{\armza}%            Lower-case z  (za)   letter.
\DeclareInputText{191}{\arme}%             Lower-case e' (e)    letter.
\DeclareInputText{193}{\armat}%            Lower-case u' (at)   letter.
\DeclareInputText{195}{\armto}%            Lower-case th (to)   letter.
\DeclareInputText{197}{\armzhe}%           Lower-case g' (zhe)  letter.
\DeclareInputText{199}{\armini}%           Lower-case i  (ini)  letter.
\DeclareInputText{201}{\armlyun}%          Lower-case l  (lyun) letter.
\DeclareInputText{203}{\armkhe}%           Lower-case x  (khe)  letter.
\DeclareInputText{205}{\armtsa}%           Lower-case c' (tsa)  letter.
\DeclareInputText{207}{\armken}%           Lower-case k  (ken)  letter.
\DeclareInputText{209}{\armho}%            Lower-case h  (ho)   letter.
\DeclareInputText{211}{\armdza}%           Lower-case dz (dza)  letter.
\DeclareInputText{213}{\armghat}%          Lower-case gh (ghat) letter.
\DeclareInputText{215}{\armtche}%          Lower-case j' (tche) letter.
\DeclareInputText{217}{\armmen}%           Lower-case m  (men)  letter.
\DeclareInputText{219}{\armhi}%            Lower-case y  (hi)   letter.
\DeclareInputText{221}{\armnu}%            Lower-case n  (nu)   letter.
\DeclareInputText{223}{\armsha}%           Lower-case sh (sha)  letter.
\DeclareInputText{225}{\armvo}%            Lower-case o  (vo)   letter.
\DeclareInputText{227}{\armcha}%           Lower-case ch (cha)  letter.
\DeclareInputText{229}{\armpe}%            Lower-case p  (pe)   letter.
\DeclareInputText{231}{\armje}%            Lower-case j  (je)   letter.
\DeclareInputText{233}{\armra}%            Lower-case r' (ra)   letter.
\DeclareInputText{235}{\armse}%            Lower-case s  (se)   letter.
\DeclareInputText{237}{\armvev}%           Lower-case v  (vev)  letter.
\DeclareInputText{239}{\armtyun}%          Lower-case t  (tyun) letter.
\DeclareInputText{241}{\armre}%            Lower-case r  (re)   letter.
\DeclareInputText{243}{\armtso}%           Lower-case c  (tso)  letter.
\DeclareInputText{245}{\armvyun}%          Lower-case w  (vyun) letter.
\DeclareInputText{247}{\armpyur}%          Lower-case ph (pyur) letter.
\DeclareInputText{249}{\armke}%            Lower-case q  (ke)   letter.
\DeclareInputText{251}{\armo}%             Lower-case o' (o)    letter.
\DeclareInputText{253}{\armfe}%            Lower-case f  (fe)   letter.


%% Miscelanious symbols.
%%
\DeclareInputText{160}{~}%                 Non-breakable space             symbol.
\DeclareInputText{161}{\armeternity}%      Eternity (armeternity)          symbol.
\DeclareInputText{162}{\armsection}%       Section sign (armsection)       symbol.
\DeclareInputText{163}{\armfullstop}%      Verjaket (armfullstop)          symbol.
\DeclareInputText{164}{\armparenright}%    Aj phakagic' (armparenright)    symbol.
\DeclareInputText{165}{\armparenleft}%     Dzax phakagic' (armparenleft)   symbol.
\DeclareInputText{166}{\armquotright}%     Aj chakert (armquotright)       symbol.
\DeclareInputText{167}{\armquotleft}%      Dzax chakert(armquotleft)       symbol.
\DeclareInputText{168}{\armemdash}%        Anjatman gic' (armemdash)       symbol.
\DeclareInputText{169}{\armdot}%           Mijaket (armdot)                symbol.
\DeclareInputText{170}{\armsep}%           Buth (armsep)                   symbol.
\DeclareInputText{171}{\armcomma}%         Storaket (armcoma)              symbol.
\DeclareInputText{172}{\armendash}%        Miuthyan gc'ik (armendash)      symbol.
\DeclareInputText{173}{\armyentamna}%      Toghadardzi nshan (armyentamna) symbol.
\DeclareInputText{174}{\armellipsis}%      Kaxman keter (armellipsis)      symbol.
\DeclareInputText{175}{\armexclam}%        Bacakanchakan nshan (armexclam) symbol.
\DeclareInputText{176}{\armaccent}%        Shesht (armaccent)              symbol.
\DeclareInputText{177}{\armquestion}%      Harcakan nshan (armquestion)    symbol.
\DeclareInputText{254}{\armapostrophe}%    Apatharc (armapostrophe)        symbol.
% Coding "armapostrophe" as 255 (except as 254), since it can
% be found in that position in many ArmSCII8 fonts.
\DeclareInputText{255}{\armapostrophe}%    Apatharc (armapostrophe)        symbol.


%% Providing a command to define armew.
%%
\def\definearmew@error{%
  \PackageError{armtex}
    {Character\space used\space to\space define\space armew\space must\MessageBreak
     have\space a\space charcode\space between\space 128\space and\space 255}
    {Change\space the\space character\space used\space in\space
     \protect\definearmew\space and\space recompile.}}

\providecommand\definearmew[1]{%
  \count@=`#1\relax
  \ifnum \count@ < 128\definearmew@error\else
  \ifnum \count@ > 255\definearmew@error\else
  \DeclareInputText{\count@}{\armew}\fi\fi}


%% That's all, Folks!
%%
\endinput
